aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/views.php
diff options
context:
space:
mode:
authorcash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-12-08 01:19:38 +0000
committercash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-12-08 01:19:38 +0000
commitd7adaddab7189bc493d22d96fec424aedca09b11 (patch)
treeebfd5c994083bed934bbd23fa403cadf778849fa /engine/lib/views.php
parente8380d051e50abec45b8ad3ed84ae57644b017d5 (diff)
downloadelgg-d7adaddab7189bc493d22d96fec424aedca09b11.tar.gz
elgg-d7adaddab7189bc493d22d96fec424aedca09b11.tar.bz2
reorganized the page views as discussed
git-svn-id: http://code.elgg.org/elgg/trunk@7559 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'engine/lib/views.php')
-rw-r--r--engine/lib/views.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/engine/lib/views.php b/engine/lib/views.php
index 26d48be2f..6fd6cfb8c 100644
--- a/engine/lib/views.php
+++ b/engine/lib/views.php
@@ -552,7 +552,7 @@ function extend_view($view, $view_name, $priority = 501, $viewtype = '') {
*
* @param string $title Title
* @param string $body Body
- * @param string $page_shell Optional page shell to use. See page_shells view directory
+ * @param string $page_shell Optional page shell to use. See page/shells view directory
* @param array $vars Optional vars array to pass to the page
* shell. Automatically adds title, body, and sysmessages
*
@@ -578,7 +578,7 @@ function elgg_view_page($title, $body, $page_shell = 'default', $vars = array())
$vars['sysmessages'] = $messages;
// Draw the page
- $output = elgg_view("page_shells/$page_shell", $vars);
+ $output = elgg_view("page/shells/$page_shell", $vars);
$vars['page_shell'] = $page_shell;
@@ -884,7 +884,7 @@ function elgg_view_entity_annotations(ElggEntity $entity, $full = true) {
/**
* Returns a rendered title.
*
* This is a shortcut for {@elgg_view page_elements/title}.
*
* @param string $title The page title
* @param string $submenu Should a submenu be displayed? (default false, use not recommended and deprecated)
@@ -896,7 +896,7 @@ function elgg_view_title($title, $submenu = false) {
elgg_deprecated_notice('setting $submenu in elgg_view_title() is deprecated', 1.8);
}
- $title = elgg_view('page_elements/title', array('title' => $title, 'submenu' => $submenu));
+ $title = elgg_view('layout/elements/title', array('title' => $title, 'submenu' => $submenu));
return $title;
}
@@ -884,7 +884,7 @@ function elgg_view_entity_annotations(ElggEntity $entity, $full = true) {
* Returns a rendered title.
*
- * This is a shortcut for {@elgg_view page_elements/title}.
+ * This is a shortcut for {@elgg_view layout/elements/title}.
*
* @param string $title The page title